# paxrelabel

Package-level PaX flag management tool.

In essence, `paxrelabel` represents the modern way of managing PaX
exception flags on a per-package basis.  Rule definition files are
installed into either `/etc/paxrelabel.d` or `/usr/share/paxrelabel.d`,
and running `paxrelabel` will load these definitions and
appropriately relabel binaries with the appropriate exception flags.

This allows for package maintainers to provide a simple set of
exceptions with their package without having to manage PaX-specific
policies in their APKBUILDs, allowing users to decide whether to
use PaX exception policies or not.

Additionally, the decoupling of PaX exception policies from the
physical package content allows for other teams and maintainers to
provide their own PaX exception policies for a specific program
in other packages.

To explain, let's take a look at a basic APKBUILD which distributes
a PaX exception compatible with `paxrelabel`:

```shell
pkgname="foo"
pkgver="1.0"
pkgrel=0
subpackages="... $pkgname-paxlabels"

paxlabels() {
	install_if="$pkgname=$pkgver-r$pkgrel paxrelabel"
	mkdir -p "$subpkgdir"/usr/share/paxrelabel.d
	echo "pemrs /usr/bin/foo" >> "$subpkgdir"/usr/share/paxrelabel.d/$pkgname
}
```

If users have `paxrelabel` installed, and they install the parent
package, then `foo-paxlabels` will also be installed due to the
`install_if` rule.

This works alongside the `paxrelabel` package which includes a
trigger that relabels the filesystem when it is run.

However, the parent package does not itself need to provide a
`-paxlabels` subpackage.  It is also possible for other maintainers
to build their own packages using the same basic pattern.
